#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Encodings.SymbolicExpressionTreeEncoding;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Problems.GeneticProgramming.GlucosePrediction {
  [StorableClass]
  [Item(CurvedChVariableSymbol.Name, "")]
  public class CurvedChVariableSymbol : Symbol {
    public new const string Name = "CurvedChVariableSymbol";
    #region Properties

    [Storable]
    private double alpha;
    public double Alpha {
      get { return alpha; }
      set {
        if (value != alpha) {
          alpha = value;
          OnChanged(EventArgs.Empty);
        }
      }
    }

    [Storable]
    private double beta;
    public double Beta {
      get { return beta; }
      set {
        if (value != beta) {
          alpha = value;
          OnChanged(EventArgs.Empty);
        }
      }
    }

    private const int minimumArity = 0;
    private const int maximumArity = 0;

    public override int MinimumArity {
      get { return minimumArity; }
    }

    public override int MaximumArity {
      get { return maximumArity; }
    }
    #endregion

    [StorableHook(HookType.AfterDeserialization)]
    private void AfterDeserialization() {
    }

    [StorableConstructor]
    protected CurvedChVariableSymbol(bool deserializing)
      : base(deserializing) {
    }

    protected CurvedChVariableSymbol(CurvedChVariableSymbol original, Cloner cloner)
      : base(original, cloner) {
      alpha = original.alpha;
      beta = original.beta;
    }

    public CurvedChVariableSymbol(string name, string desc, double alpha, double beta)
      : base(name, desc) {
      this.alpha = alpha;
      this.beta = beta;
    }

    public override ISymbolicExpressionTreeNode CreateTreeNode() {
      return new CurvedChVariableTreeNode(this);
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new CurvedChVariableSymbol(this, cloner);
    }
  }
}
