#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Encodings.SymbolicExpressionTreeEncoding;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;
using HeuristicLab.Random;
namespace HeuristicLab.Problems.GeneticProgramming.GlucosePrediction {
  [StorableClass]
  public class CurvedChVariableTreeNode : SymbolicExpressionTreeTerminalNode {
    public new CurvedChVariableSymbol Symbol {
      get { return (CurvedChVariableSymbol)base.Symbol; }
    }
    [StorableConstructor]
    protected CurvedChVariableTreeNode(bool deserializing) : base(deserializing) { }
    protected CurvedChVariableTreeNode(CurvedChVariableTreeNode original, Cloner cloner)
      : base(original, cloner) {
    }
    protected CurvedChVariableTreeNode() { }
    public CurvedChVariableTreeNode(CurvedChVariableSymbol variableSymbol) : base(variableSymbol) { }

    public override bool HasLocalParameters {
      get { return false; }
    }

    public override void ResetLocalParameters(IRandom random) {
      base.ResetLocalParameters(random);
    }

    public override void ShakeLocalParameters(IRandom random, double shakingFactor) {
      base.ShakeLocalParameters(random, shakingFactor);
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new CurvedChVariableTreeNode(this, cloner);
    }

    public override string ToString() {
      return string.Format("curvedCh(alpha: {0}, beta: {1})", Symbol.Alpha, Symbol.Beta);
    }
  }
}
